==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/hu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A CPU információk nem érhetők el",
    "Load average: {cpu} (last minute)" : "Terhelési átlag: {cpu} (utolsó perc)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Összesen: {memTotalBytes}/Jelenlegi használat: {memUsageBytes}",
    "RAM info not available" : "A RAM információk nem érhetők el",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "CSEREHELY: Összesen: {swapTotalBytes}/Jelenlegi használat: {swapUsageBytes}",
    "SWAP info not available" : "A cserehely információk nem érhetők el",
    "Users" : "Felhasználók",
    "Groups" : "Csoportok",
    "Links" : "Hivatkozások",
    "Emails" : "E-mailek",
    "Federated sent" : "Föderáltak elküldve",
    "Federated received" : "Föderáltak fogadva",
    "Talk conversations" : "Beszélgetések",
    "24 hours" : "24 óra",
    "1 hour" : "1 óra",
    "5 mins" : "5 perc",
    "Copy" : "Másolás",
    "Copied!" : "Másolva!",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "A másoláshoz nyomjon ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomjon Ctrl-C-t.",
    "System" : "Rendszer",
    "Monitoring" : "Rendszerfelügyelet",
    "Monitoring app with useful server information" : "Rendszerfelügyeleti alkalmazás hasznos kiszolgálóinformációkkal",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Hasznos kiszolgálóinformációk nyújtása, mint a CPU terhelés, RAM foglaltság, felhasználók száma, stb.",
    "Operating System:" : "Operációs rendszer:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Ismeretlen processzor",
    "Memory:" : "Memória:",
    "Server time:" : "Kiszolgálóidő:",
    "Uptime:" : "Működési idő:",
    "Temperature" : "Hőmérséklet",
    "Load" : "Terhelés",
    "Memory" : "Memória",
    "Disk" : "Lemez",
    "Mount:" : "Csatolás:",
    "Filesystem:" : "Fájlrendszer:",
    "Size:" : "Méret:",
    "Available:" : "Elérhető:",
    "Used:" : "Használt:",
    "You will get a notification once one of your disks is nearly full." : "Értesítést fog kapni, ha a lemezek már majdnem megteltek.",
    "Files:" : "Fájlok:",
    "Storages:" : "Tárhelyek:",
    "Free Space:" : "Szabad hely:",
    "Network" : "Hálózat",
    "Hostname:" : "Gépnév:",
    "DNS:" : "DNS:",
    "Gateway:" : "Átjáró:",
    "Status:" : "Állapot:",
    "Speed:" : "Sebesség:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktív felhasználók",
    "Total users:" : "Összes felhasználó:",
    "Shares" : "Megosztások",
    "PHP" : "PHP",
    "Version:" : "Verzió:",
    "Memory limit:" : "Memóriakorlát:",
    "Max execution time:" : "Maximális végrehajtási idő:",
    "Upload max size:" : "Maximális feltöltési méret:",
    "Extensions:" : "Bővítmények:",
    "Unable to list extensions" : "Nem lehet felsorolni a bővítményeket",
    "Database" : "Adatbázis:",
    "Type:" : "Típus:",
    "External monitoring tool" : "Külső rendszerfelügyeleti eszköz",
    "You can connect an external monitoring tool by using this end point:" : "Ennek a végpontnak a használatával külső rendszerfelügyeleti eszközt csatlakoztathat:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ha hozzáfűzi a „?format=json” szöveget az URL végéhez, akkor az eredményt JSON formátumban adja meg.",
    "To use an access token, please generate one then set it using the following command:" : "A hozzáférési token használatához hozzon létre egyet, majd állítsa be a következő paranccsal:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ezután adja át a tokent az „NC-Token” fejléccel, amikor lekérdezi a fenti URL-t.",
    "Operating System" : "Operációs rendszer",
    "CPU" : "CPU",
    "Server time" : "Kiszolgálóidő",
    "Uptime" : "Működési idő",
    "Mount" : "Csatolás",
    "Filesystem" : "Fájlrendszer",
    "Size" : "Méret",
    "Available" : "Elérhető",
    "Used" : "Használt",
    "Files" : "Fájlok",
    "Storages" : "Tároló",
    "Free Space" : "Szabad hely",
    "Hostname" : "Gépnév",
    "DNS" : "DNS",
    "Gateway" : "Átjáró",
    "Status" : "Állapot",
    "Speed" : "Sebesség",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Total users" : "Összes felhasználó",
    "Version" : "Verzió",
    "Memory limit" : "Memória korlát",
    "Max execution time" : "Maximális végrehajtási idő",
    "Upload max size" : "Maximális feltöltési méret",
    "Type" : "Típus",
    "You can connect an external monitoring tool by using this end point" : "Ennek a végpontnak a használatával külső rendszerfelügyeleti eszközt csatlakoztathat",
    "To use an access token, please generate one then set it using the following command" : "A hozzáférési token használatához hozzon létre egyet, majd állítsa be a következő paranccsal"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/hu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A CPU információk nem érhetők el",
    "Load average: {cpu} (last minute)" : "Terhelési átlag: {cpu} (utolsó perc)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Összesen: {memTotalBytes}/Jelenlegi használat: {memUsageBytes}",
    "RAM info not available" : "A RAM információk nem érhetők el",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "CSEREHELY: Összesen: {swapTotalBytes}/Jelenlegi használat: {swapUsageBytes}",
    "SWAP info not available" : "A cserehely információk nem érhetők el",
    "Not supported!" : "Nem támogatott!",
    "Press ⌘-C to copy." : "A másoláshoz nyomjon ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomjon Ctrl-C-t.",
    "System" : "Rendszer",
    "Monitoring" : "Rendszerfelügyelet",
    "Monitoring app with useful server information" : "Rendszerfelügyeleti alkalmazás hasznos kiszolgálóinformációkkal",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Hasznos kiszolgálóinformációk nyújtása, mint a CPU terhelés, RAM foglaltság, felhasználók száma, stb.",
    "Operating System:" : "Operációs rendszer:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Ismeretlen processzor",
    "Memory:" : "Memória:",
    "Server time:" : "Kiszolgálóidő:",
    "Uptime:" : "Működési idő:",
    "Temperature" : "Hőmérséklet",
    "Load" : "Terhelés",
    "Memory" : "Memória",
    "Disk" : "Lemez",
    "Mount:" : "Csatolás:",
    "Filesystem:" : "Fájlrendszer:",
    "Size:" : "Méret:",
    "Available:" : "Elérhető:",
    "Used:" : "Használt:",
    "Files:" : "Fájlok:",
    "Storages:" : "Tárhelyek:",
    "Free Space:" : "Szabad hely:",
    "Network" : "Hálózat",
    "Hostname:" : "Gépnév:",
    "DNS:" : "DNS:",
    "Gateway:" : "Átjáró:",
    "Status:" : "Állapot:",
    "Speed:" : "Sebesség:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktív felhasználók",
    "Total users:" : "Összes felhasználó:",
    "24 hours:" : "24 óra:",
    "1 hour:" : "1 óra:",
    "5 mins:" : "5 perc:",
    "Shares" : "Megosztások",
    "Users:" : "Felhasználók:",
    "Groups:" : "Csoportok:",
    "Links:" : "Hivatkozások:",
    "Emails:" : "E-mailek:",
    "Federated sent:" : "Föderáltak elküldve:",
    "Federated received:" : "Föderáltak fogadva:",
    "Talk conversations:" : "Beszélgetések:",
    "PHP" : "PHP",
    "Version:" : "Verzió:",
    "Memory limit:" : "Memóriakorlát:",
    "Max execution time:" : "Maximális végrehajtási idő:",
    "Upload max size:" : "Maximális feltöltési méret:",
    "OPcache Revalidate Frequency:" : "OPcache újraellenőrzési gyakorisága:",
    "Extensions:" : "Bővítmények:",
    "Unable to list extensions" : "Nem lehet felsorolni a bővítményeket",
    "Show phpinfo" : "phpinfo mutatása",
    "Database" : "Adatbázis:",
    "Type:" : "Típus:",
    "External monitoring tool" : "Külső rendszerfelügyeleti eszköz",
    "You can connect an external monitoring tool by using this end point:" : "Ennek a végpontnak a használatával külső rendszerfelügyeleti eszközt csatlakoztathat:",
    "Copy" : "Másolás",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Ha hozzáfűzi a „?format=json” szöveget az URL végéhez, akkor az eredményt JSON formátumban adja meg.",
    "To use an access token, please generate one then set it using the following command:" : "A hozzáférési token használatához hozzon létre egyet, majd állítsa be a következő paranccsal:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ezután adja át a tokent az „NC-Token” fejléccel, amikor lekérdezi a fenti URL-t.",
    "You will get a notification once one of your disks is nearly full." : "Értesítést fog kapni, ha a lemezek már majdnem megteltek."
},
"nplurals=2; plural=(n != 1);");
